@@ -771,6 +771,19 @@ nautilus_directory_is_remote (NautilusDirectory *directory)
     return is_remote;
 }
 
+gboolean
+nautilus_directory_is_in_admin (NautilusDirectory *directory)
+{
+    g_assert (NAUTILUS_IS_DIRECTORY (directory));
+
+    if (directory->details->location == NULL)
+    {
+        return FALSE;
+    }
+
+    return g_file_has_uri_scheme (directory->details->location, "admin");
+}
+
 gboolean
 nautilus_directory_are_all_files_seen (NautilusDirectory *directory)
 {
