@@ -41,7 +41,6 @@
 
 #include <eel/eel-debug.h>
 #include <eel/eel-gtk-extensions.h>
-#include <eel/eel-stock-dialogs.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
@@ -983,7 +982,7 @@ notify_unmount_done (GMountOperation *op,
         gchar **strings;
 
         strings = g_strsplit (message, "\n", 0);
-        icon = g_themed_icon_new ("media-removable");
+        icon = g_themed_icon_new ("media-removable-symbolic");
         unplug = g_notification_new (strings[0]);
         g_notification_set_body (unplug, strings[1]);
         g_notification_set_icon (unplug, icon);
@@ -1067,7 +1066,7 @@ places_sidebar_show_error_message_cb (GtkPlacesSidebar *sidebar,
 {
     NautilusWindow *window = NAUTILUS_WINDOW (user_data);
 
-    eel_show_error_dialog (primary, secondary, GTK_WINDOW (window));
+    show_error_dialog (primary, secondary, GTK_WINDOW (window));
 }
 
 static void
@@ -1839,7 +1838,6 @@ notebook_popup_menu_show (NautilusWindow *window,
 {
     GtkWidget *popup;
     GtkWidget *item;
-    int button, event_time;
     gboolean can_move_left, can_move_right;
     NautilusNotebook *notebook;
 
@@ -1887,24 +1885,8 @@ notebook_popup_menu_show (NautilusWindow *window,
 
     gtk_widget_show_all (popup);
 
-    if (event)
-    {
-        button = event->button;
-        event_time = event->time;
-    }
-    else
-    {
-        button = 0;
-        event_time = gtk_get_current_event_time ();
-    }
-
-    /* TODO is this correct? */
-    gtk_menu_attach_to_widget (GTK_MENU (popup),
-                               window->priv->notebook,
-                               NULL);
-
-    gtk_menu_popup (GTK_MENU (popup), NULL, NULL, NULL, NULL,
-                    button, event_time);
+    gtk_menu_popup_at_pointer (GTK_MENU (popup),
+                               (GdkEvent*) event);
 }
 
 /* emitted when the user clicks the "close" button of tabs */
